@@ -19,9 +19,7 @@ c                         east-down). The unit is T.
 c  icon:  output. integer*4  0---> o.k
 c                            1---> input parameter wrong.
 c
-c  according to rikanenpyou 1990. ed.
-c          accuracy depends on the place.  at good place, 2 digit
-c       can be obtained accurately.
+
 c
        subroutine cgeomag(yearin, llh, h,  icon)
        implicit none
@@ -37,20 +35,21 @@ c
 c     ************************************
       integer nmax
       parameter (nmax = 12)
-      real*8 gnm(nmax, 0:nmax), hnm(nmax, nmax), year
-      real*8 gnmd(nmax, 0:nmax), hnmd(nmax, nmax)
+      real*4 gnm(nmax, 0:nmax), hnm(nmax, nmax), year
+      real*4 gnmd(nmax, 0:nmax), hnmd(nmax, nmax)
       integer nmx
       common /ZmagCoef/  gnm, gnmd, hnm, hnmd, year, nmx
 c     ************************************      
 
 c
 c
-       real*8 r, sumn, sume, sumd, t, cost, sint, x, tlonr, gmnc, 
-     *       cosml, sinml, hmnc,  gn, ge, gd, temp
-       real*8 ssumd, ssumn, ssume 
+       real*4 r, sumn, sume, sumd, t, cost, sint, x, tlonr, gmnc, 
+     *       cosml, sinml, hmnc, temp
+       real*8 gn, ge, gd
+       real*4 ssumd, ssumn, ssume 
        integer m, n
        record /coord/ cdata
-       real*8 kdpmnxsinn, kpmnxn, kpmnxisinn
+       real*4 kdpmnxsinn, kpmnxn, kpmnxisinn
 
 c
 c         check data type
@@ -60,23 +59,25 @@ c         check data type
           call ctransCoord2('llh', llh, cdata)
        endif   
 c
+       icon =  0
        if( abs(yearin-year) .gt. 7.) then
            icon=1
            call cerrorMsg(
      *     ' Year spec. for geomag data is invalid.', 1)
 c       elseif(abs(cdata.lat) .gt. 90.) then
-       elseif(abs(cdata.r(1)) .gt. 90.) then
+       elseif(abs(cdata.r(1)) .gt. 90.5d0) then
            icon=2
 c       elseif(abs(cdata.long) .gt. 360.) then
-       elseif(abs(cdata.r(2)) .gt. 360.) then
+       elseif(abs(cdata.r(2)) .gt. 360.5d0) then
            icon=2
 c       elseif(cdata.h .gt. 5000.d3) then
-       elseif(cdata.r(3) .gt. 10000.d4) then
+       elseif(cdata.r(3) .gt. 100000.d3) then
            icon=1
 c       elseif(cdata.h .lt. -3000.d3) then
        elseif(cdata.r(3) .lt. -3000.d3) then
            icon=1
-       else
+       endif
+       if(icon .ne. 2) then
 c           r=1./( 1.+cdata.h/Eradius )
            r=1./( 1.+cdata.r(3)/Eradius )
            sumn=0.
@@ -117,13 +118,12 @@ c           tlonr=cdata.long*Torad
           enddo
 c              original formula gives  data in nT.
 c              north component
-          gn = -sumn /1.d9  ! to T.
+          gn = -sumn /1.e9  ! to T.
 c              east  component
-          ge = -sume /1.d9
+          ge = -sume /1.e9
 c              down
-          gd = -sumd /1.d9
+          gd = -sumd /1.e9
           call csetMagField('ned', gn, ge, gd, h)
-          icon=0
        endif
        if(icon .eq. 2) then
           call cerrorMsg('Geometrical input data wrong', 0)
@@ -141,8 +141,8 @@ c    #include "Zmanagerp.h"
 c     ************************************
       integer nmax
       parameter (nmax = 12)
-      real*8 gnm(nmax, 0:nmax), hnm(nmax, nmax), year
-      real*8 gnmd(nmax, 0:nmax), hnmd(nmax, nmax)
+      real*4 gnm(nmax, 0:nmax), hnm(nmax, nmax), year
+      real*4 gnmd(nmax, 0:nmax), hnmd(nmax, nmax)
       integer nmx
       common /ZmagCoef/  gnm, gnmd, hnm, hnmd, year, nmx
 c     ************************************      
@@ -198,14 +198,15 @@ c     *************************
 
       integer i, j, store, m, n
       character*64  msg
-      real*8 yearx,  dy, coef, g, h, dg, dh
+      character*80  msg2
+      real*4 yearx,  dy, coef, g, h, dg, dh
 
 
 c     ************************************
       integer nmax
       parameter (nmax = 12)
-      real*8 gnm(nmax, 0:nmax), hnm(nmax, nmax), year
-      real*8 gnmd(nmax, 0:nmax), hnmd(nmax, nmax)
+      real*4 gnm(nmax, 0:nmax), hnm(nmax, nmax), year
+      real*4 gnmd(nmax, 0:nmax), hnmd(nmax, nmax)
       integer nmx
       common /ZmagCoef/  gnm, gnmd, hnm, hnmd, year, nmx
 c     ************************************      
@@ -213,7 +214,7 @@ c     ************************************
 
       rewind  devn
       store = 0
-
+      nmx = 0
 c       first find the appropriate year
       
       read(devn, '(a)', end=1000) msg
@@ -244,22 +245,22 @@ c                       new year appeared
      *                 m, n, g, h, dg, dh
                   if( n .gt. nmax ) then
                      call cerrorMsg(msg, 1)
-                     write(msg,*)
+                     write(msg2,*)
      *                    ' n=',n, ' for  geomag  data > ', nmx
-                     call cerrorMsg(msg, 0)
+                     call cerrorMsg(msg2, 0)
                   endif
                   nmx = max(n, nmx)
                   if(n .le. 0) then
-                     call cerrorMsg(msg, 1)
-                     write(msg,*)
+                     call cerrorMsg(msg2, 1)
+                     write(msg2,*)
      *                    ' n=',n, ' for  geomag data <=0'
-                     call cerrorMsg(msg, 0)
+                     call cerrorMsg(msg2, 0)
                   endif
                   if(m .lt. 0 .or. m .gt. n) then
-                     call cerrorMsg(msg, 1)
-                     write(msg,*)
+                     call cerrorMsg(msg2, 1)
+                     write(msg2,*)
      *                    ' m=',m, ' for   geomag data < 0 or > n'
-                     call cerrorMsg(msg, 0)
+                     call cerrorMsg(msg2, 0)
                   endif
                   if(store .eq. 1) then
                      gnm(n, m) = g
@@ -321,14 +322,14 @@ c     *************************
 
       integer i, j, store, m, n
       character*100  msg
-      real*8 yearx,  dy, coef, g, h, dg, dh
+      real*4 yearx,  dy, coef, g, h, dg, dh
 
 
 c     ************************************
       integer nmax
       parameter (nmax = 12)
-      real*8 gnm(nmax, 0:nmax), hnm(nmax, nmax), year
-      real*8 gnmd(nmax, 0:nmax), hnmd(nmax, nmax)
+      real*4 gnm(nmax, 0:nmax), hnm(nmax, nmax), year
+      real*4 gnmd(nmax, 0:nmax), hnmd(nmax, nmax)
       integer nmx
       common /ZmagCoef/  gnm, gnmd, hnm, hnmd, year, nmx
 c     ************************************      
@@ -336,7 +337,7 @@ c     ************************************
 
       rewind  devn
       store = 0
-
+      nmx = 0
 c       first find the appropriate year
       
       read(devn, '(a)', end=1000) msg
@@ -371,7 +372,8 @@ c                              not m, n(cf; IGRF)
                      if( n .gt. nmax ) then
                         call cerrorMsg(msg, 1)
                         write(msg,*)
-     *                 ' n=',n, ' for  geomag  data > ', nmx
+     *                  ' n=',n, ' for  geomag  data > ',
+     *                  nmax
                         call cerrorMsg(msg, 0)
                      endif
                      nmx = max(n, nmx)
@@ -453,8 +455,8 @@ c        print current geomag coeff.
 c     ************************************
       integer nmax
       parameter (nmax = 12)
-      real*8 gnm(nmax, 0:nmax), hnm(nmax, nmax), year
-      real*8 gnmd(nmax, 0:nmax), hnmd(nmax, nmax)
+      real*4 gnm(nmax, 0:nmax), hnm(nmax, nmax), year
+      real*4 gnmd(nmax, 0:nmax), hnmd(nmax, nmax)
       integer nmx
       common /ZmagCoef/  gnm, gnmd, hnm, hnmd, year, nmx
 c     ************************************      
