@@ -3,6 +3,7 @@ c
       subroutine cbeginRun
       implicit none
 #include  "Zmanagerp.h"
+#include  "Zmanager.h"
 #include  "Zelemagp.h"
 #include  "Zevhnp.h"
 #include  "Ztrack.h"
@@ -15,14 +16,16 @@ c
 #include  "Zobs.h"
 #include  "Zobsp.h"
 
-      character*70 msg
+
       character*16 temp
       integer jold, icon
       real*8 s1
 
+
       if(Cont) then
 c           restore status at the end of previous run
          call crestoreStatus
+         Cont =.true.
       elseif(Job .eq. 'flesh' ) then
          call cgetSkelFile 
          Job = 'flesh'    ! Job='flesh' is kept as now
@@ -62,18 +65,8 @@ c         to lower case letters.
 
       call rndsw(jold, 1)    ! specify random number generator 1.
 
-      if(IntModel .eq. 'int1') then
-c           for Lund init.  
-         call haddenC
-         call chanwnC
-      elseif(IntModel .eq. 'int2') then
-c         Gheisha; init. Gheisha cannot use hadrin/nucrin in Cosmos
-         call gpart
-         call gheini
-      else
-         write(msg, *) 'IntModel=', IntModel,' not supported'
-         call cerrorMsg(msg, 0)
-      endif
+      call cintModels('cosmos')  ! analysis of interaction models and init.
+
 #if ATMOSPHERE == 1
 c          read segmented atmosphere data
       call creadAtmosD
@@ -117,9 +110,12 @@ c           flesh time
       endif
 c         user hook
       call chookBgRun
+      
       end
+
       subroutine ciniTracking0
       implicit none
+#include  "Zmanager.h"
 #include  "Zmanagerp.h"
 #include  "Zevhnp.h"
 #include  "Ztrack.h"
@@ -133,7 +129,7 @@ c         user hook
 #include  "Zheavyv.h"
 
 c
-      integer i
+      integer i, now(2)
 
       ObserveAS = index(Generate, 'as')  .gt. 0 .or.
      *            index(Generate, 'lat') .gt. 0 
@@ -144,8 +140,17 @@ c
       endif
 
       EventsInTheRun = 0
-      if(InitRN(1) .ne. 0) then
+
+      RefreshIR = InitRN(1) .lt. 0 .and. Job .ne. 'flesh'
+
+      if(InitRN(1) .gt. 0 .and. InitRN(2) .gt. 0 ) then
          call rnd1r(InitRN)     ! init randeom number generator
+c      *****************
+      elseif(.not. RefreshIR .and. InitRN(2) .lt. 0) then
+         call time(now(1))
+         now(2) =-InitRN(2)
+         call rnd1r(now)
+c     ******************
       endif
 c          compute the offset point in 'xyz' system
 c        the deepest detector origin + Offset is the point
@@ -211,13 +216,16 @@ c                 save skeleton inf. in skelotonFile file.
 c             The file will be modified when the distjob command
 c             processes Job = 'flesh' later. You need not modify
 c             skeleton file if distjob is employed.
-            call copenfw(TempDev, SkeletonFile, icon)
-            if(icon .ne. 0) then
-               call cerrorMsg(SkeletonFile, 1)
-               call cerrorMsg('File shown above cannot be opened',0)
+            if(.not. Cont) then
+               call copenfw(TempDev, SkeletonFile, icon)
+               if(icon .ne. 0) then
+                  call cerrorMsg(SkeletonFile, 1)
+                  call cerrorMsg(
+     *              'File shown above cannot be opened',0)
+               endif
+               call cwriteParam(TempDev, 1)
+               close(TempDev)
             endif
-            call cwriteParam(TempDev, 1)
-            close(TempDev)
 c                open SeedFile 
             if(SeedFile .eq. ' ') then
 c                error. you need file
