@@ -11,9 +11,12 @@ c       ***************************************** stave  cont info
       implicit none
 #include "Zmanagerp.h"
       
+      integer icon
+
       PrevEventNo = EventNo    ! current event no.
       call rnd1s(InitRN)  !  current seed.
-      open(TempDev, file=ContFile, form='formatted')
+      call copenfw(TempDev, ContFile, icon)
+c      open(TempDev, file=ContFile, form='formatted')
       call cwriteParam(TempDev, 1)
       close(TempDev)
       end
