@@ -133,6 +133,14 @@ c        check if in the ascending order of detph
           call cerrorMsg(
      *      "ObsPlane==spherical but Za1ry !='is'",0)
        endif
+c       from v5.66
+       if(BorderHeightL .eq. 0.) then
+          BorderHeightL = ObsSites(NoOfSites).pos.height -1.0
+       endif
+       ObsSites(0).pos.height = BorderHeightH
+       ObsSites(0).pos.radiallen = BorderHeightH + Eradius
+       ObsSites(NoOfSites+1).pos.height = BorderHeightL
+       ObsSites(NoOfSites+1).pos.radiallen = BorderHeightL + Eradius
 
 c         +++++++++++++++++++++++ for AS ++++++++++++++++
        NoOfASSites = 0
@@ -150,7 +158,7 @@ c                HeightList has priority
      *    ASHeightList(i),   ASObsSites(i).pos.xyz )
        enddo
  200   continue
- 
+       
 c          site coord is made  to be in the  xyz system.       
        do i = 1, NoOfASSites
           call ctransCoord2('xyz', ASObsSites(i).pos.xyz,
