@@ -70,6 +70,7 @@ c----       include 'Ztrack.h'
 #include  "Ztrack.h"
 c----       include 'Ztrackv.h'
 #include  "Ztrackv.h"
+#include  "Zelemagp.h"
 c     
        integer cg
        real*8 e1, er, tmp, cos1, cosr, sine, cs, sn, sinr
@@ -78,11 +79,11 @@ c
        record /track/ aTrack
 c
        if(cg .eq. -1) then
-          call cmollerEnergy(MovedTrack.p.fm.p(4), e1, er)
-          call cmollerAngle(cos1, cosr)
+          call cmollerea(MovedTrack.p.fm.p(4), RecoilKineMinE,
+     *                   e1, er, cos1, cosr)
        else
-          call cbhabhaEnergy(MovedTrack.p.fm.p(4), e1, er)
-          call cbhabhaAngle(cos1, cosr)
+          call cbhabhaea(MovedTrack.p.fm.p(4), RecoilKineMinE,
+     *    e1, er, cos1, cosr)
        endif
 
        tmp=1.d0-cos1*cos1
@@ -143,8 +144,7 @@ c----       include 'Ztrackv.h'
        record /track/aTrack
        record /coord/ dc, dc1, dcr
 c
-       call canihiEnergy(MovedTrack.p.fm.p(4), e1, er)
-       call canihiAngle(cos1, cosr)
+       call canihiea(MovedTrack.p.fm.p(4), e1, er, cos1, cosr)
 c               
        tmp=1.d0-cos1*cos1
        if(tmp .lt. 0.d0) then
