@@ -29,8 +29,11 @@ c           (except for hadronic interactions)
             call cinteNuc
          elseif(MovedTrack.p.code .eq. kmuon) then
             call cinteMuon
-         elseif(MovedTrack.p.code .ge. kdeut .and.
+         elseif( MovedTrack.p.code .eq. kgnuc ) then
+            call cinteHeavy
+         elseif(MovedTrack.p.code .ge. kalfa .and.
      *           MovedTrack.p.code .le. khvymax  ) then
+ccc            elseif(MovedTrack.p.code .ge. kdeut .and.
             call cinteHeavy
          elseif(MovedTrack.p.code .eq. ktriton) then
             call cinteHeavy
@@ -42,6 +45,16 @@ c           (except for hadronic interactions)
             call cinteddb
          elseif(MovedTrack.p.code .eq. keta) then
             call cinteEta
+         elseif(MovedTrack.p.code .eq. kgzai) then
+            call cinteGzai
+         elseif(MovedTrack.p.code .eq. kbomega) then
+            call cinteBomega
+         elseif(MovedTrack.p.code .eq. klambda) then
+            call cinteLambda
+         elseif(MovedTrack.p.code .eq. klambdac) then
+            call cinteLambdac
+         elseif(MovedTrack.p.code .eq. ksigma) then
+            call cinteSigma
          else
             write(msg, *) ' ptcl =', MovedTrack.p.code,
      *        ' interaction=', 
