@@ -18,6 +18,7 @@ c
       integer neverNEP/0/,  neverE/0/,  neverG/0/
       save  neverNEP, neverE, neverG
       integer never
+      save never
 
       record /ptcl/ fragA(maxHeavyMassN),  nonIntNucA(maxHeavyMassN)
       integer noOfFrag, noOfNonIntN
@@ -69,10 +70,10 @@ c                 stack the leading ptcl  first (to save stack area)
          endif
       elseif(never .eq. 2) then
 c              save only fragments and non interacting nucleons
-         if(MovedTrack.p.code .ge. kdeut .and. 
-     *      MovedTrack.p.code .le. khvymax ) then
+cc         if(MovedTrack.p.code .ge. kdeut .and. 
+cc     *      MovedTrack.p.code .le. khvymax ) then
+         if(MovedTrack.p.code .eq. kgnuc ) then
 c               get fragment and non interacting nuc.
-
             call cqHvyIntF(fragA, noOfFrag)
             call cqHvyIntNIN(nonIntNucA, noOfNonIntN)
 
@@ -132,7 +133,7 @@ c
 c               reset direction cos and related stuffs
          call cresetDirec(aTrack)
 
-         aTrack.wgt=iTrack.wgt
+
          if(needThin) then
             call csetThinwgt(iTrack, aTrack,  icon)
          else
@@ -281,7 +282,7 @@ c            call cresetMom(aTrack)  which is
             aTrack.p.fm.p(3) = p * aTrack.vec.w.r(3)
 
             call cgetZenith(aTrack, aTrack.vec.coszenith)
-            aTrack.wgt = iTrack.wgt
+
             if(needThin) then
                call csetThinwgt(iTrack, aTrack, icon)
             else
@@ -330,8 +331,9 @@ c
       integer num              ! output. number of ptcls in ptclA
 c
 c
-      if(MovedTrack.p.code .ge. kdeut .and. 
-     *    MovedTrack.p.code .le. khvymax ) then
+cc      if(MovedTrack.p.code .ge. kdeut .and. 
+cc     *    MovedTrack.p.code .le. khvymax ) then
+      if( MovedTrack.p.code .eq. kgnuc ) then
          call cqHvyIntIN(ptclA, num)
       else
 #ifdef SUBSTREC
@@ -364,7 +366,7 @@ c     ***************************
       if(u .gt. iwgt) then
          icon =1                !  discard this ptcl
       else
-         aTrack.wgt = aTrack.wgt /iwgt
+         aTrack.wgt = iTrack.wgt /iwgt
          icon = 0
       endif
       end
