@@ -23,57 +23,56 @@ c
       real*8  clen2thick, erg
       integer jcut
 
+
       erg = TrackBefMove.p.fm.p(4)
-c             fix energy dependent trancation path
+c             fix energy dependent truncation path
       if(TrackBefMove.p.charge .ne. 0) then
 
-c          magnetic
-
+c            magnetic
          call cmagDefR(TrackBefMove, Mag,  rmg)  ! get radius approx.
-         rmg = rmg/5.  !  this is almost streight movable
+         rmg = rmg/LamorDiv        !  this is almost streight movable
 c            get max length within which B is almost const
-         if(Reverse .ne. 0 .or.
-     *   (erg .gt. MagBremEmin .and. MagBrem .ne. 0 )) then
+ccc         if(Reverse .ne. 0 .or.
+ccc     *   (erg .gt. MagBremEmin .and. MagBrem .ne. 0 )) then
 c            length within which dB  < 1 %.
-            call clengSmallBC(TrackBefMove, rmgmax)  
-            rmg = min(rmg, rmgmax)
-         endif
+         call clengSmallBC(TrackBefMove, rmgmax)  
+         rmg = min(rmg, rmgmax)
+cc         endif
 
 c            mul. scatt and lpm
 
          if(Reverse .eq. 0) then
-            if(TrackBefMove.pos.height .lt. AlmostVacH) then
-               call cmaxCasLen(TrackBefMove, ztrunc)
-               if(TrackBefMove.p.fm.p(4) .gt. LpmBremEmin
+ccc            if(TrackBefMove.pos.height .lt. AlmostVacH) then
+            call cmaxCasLen(TrackBefMove, ztrunc)
+            if(TrackBefMove.p.fm.p(4) .gt. LpmBremEmin
      *         .and. LpmEffect) then
-                  ztrunc = min(TrackBefMove.pos.depth/10., ztrunc)
-               endif
-               call cthick2len(TrackBefMove.pos.height, 
-     *         TrackBefMove.vec.coszenith, ztrunc, leng, thick, jcut)
+               ztrunc = min(TrackBefMove.pos.depth/10., ztrunc)
+            endif
+c            call cthick2len(TrackBefMove.pos.height, 
+c     *         TrackBefMove.vec.coszenith, ztrunc, leng, thick, jcut)
+            call cthick2len(TrackBefMove,
+     *          ztrunc, leng, thick, jcut)
 c                 thick may have been changed to shorter one.
-
-               if(rmg .lt. leng) then
-                  thick = clen2thick(TrackBefMove.pos.height,
-     *             TrackBefMove.vec.coszenith, rmg)
-
-                  leng = rmg
-
-               endif
-            else
-               thick = AlmostVacT
+            if(rmg .lt. leng) then
+               thick = clen2thick(TrackBefMove.pos.height,
+     *              TrackBefMove.vec.coszenith, rmg)
                leng = rmg
             endif
+cc            else
+cc               thick = AlmostVacT
+cc               leng = rmg
+cc            endif
          elseif(Reverse .eq. 1) then
             leng = rmg
             thick = 0.
          else
             leng = rmg
-            if(TrackBefMove.pos.height .gt. AlmostVacH) then
-               thick = 0.
-            else
+cc            if(TrackBefMove.pos.height .gt. AlmostVacH) then
+cc               thick = 0.
+cc            else
                thick = clen2thick(TrackBefMove.pos.height,
      *         TrackBefMove.vec.coszenith, rmg)
-            endif
+cc            endif
          endif
       else
 c               neutral
@@ -101,8 +100,10 @@ c               neutral
                else
                   ztrunc = X0*5
                endif
-               call cthick2len(TrackBefMove.pos.height, 
-     *         TrackBefMove.vec.coszenith, ztrunc, leng, thick, jcut)
+c               call cthick2len(TrackBefMove.pos.height, 
+c     *         TrackBefMove.vec.coszenith, ztrunc, leng, thick, jcut)
+               call cthick2len(TrackBefMove,
+     *            ztrunc, leng, thick, jcut)
 c                 thick may have been changed to shorter one.
                if(rmg .lt. leng) then
                   thick = clen2thick(TrackBefMove.pos.height,
@@ -118,12 +119,12 @@ c                 thick may have been changed to shorter one.
             thick = 0.
          else
             leng = rmg
-            if(TrackBefMove.pos.height .gt. AlmostVacH) then
-               thick = 0.
-            else
+cc            if(TrackBefMove.pos.height .gt. AlmostVacH) then
+cc               thick = 0.
+cc            else
                thick = clen2thick(TrackBefMove.pos.height,
      *         TrackBefMove.vec.coszenith, rmg)
-            endif
+cc            endif
          endif
       endif
       end
@@ -177,6 +178,9 @@ c       approximate one.
       else
          maxb = max (abs(mag.x), abs(mag.y), abs(mag.z)) 
          if(maxb .ne. 0) then
+c               r is smaller than true Lamor radius which
+c               would be obtained with momentum
+c               since K.E < P
             r = 3.3*(aTrack.p.fm.p(4)-aTrack.p.mass)/maxb/
      *       abs(aTrack.p.charge)
             r= max(r, 1.d-2)
@@ -204,8 +208,5 @@ c     at the surface of Earth, it is about 20 km = MagChgDist
 c     at larger radial distance, it becomes larger
 c
       r =   aTrack.pos.radiallen/Eradius * MagChgDist
+
       end
-
-            
-      
-
