@@ -39,6 +39,7 @@ c            (in this case Za1ry == 'is' guaranteed).
          call cmkInc(incident, angle)
 #if LABELING > 0
          incident.info = 0
+         incident.label = 0
 #endif
 c           
          if(ObsPlane .eq. spherical) then
@@ -60,7 +61,9 @@ c              reset position and angle.
       
  10   continue
       end
-#ifdef NEXT486
+#if defined NEXT486
+#define IMAG_P dimag
+#elif defined PCLinux
 #define IMAG_P dimag
 #else
 #define IMAG_P imag
@@ -218,7 +221,7 @@ c
 #include  "Zincidentp.h"
 #include  "Zincidentv.h"
 #include  "Zearth.h"
-
+#include  "Zcode.h"
       record /track/ incident ! input/outut.
 c             must have E, m, code, subcode, charge
       record /coord/ angle    ! input. must have direction cos in the det. sys.
@@ -235,7 +238,9 @@ c           to see  cut off or to see if go out of Earth
          enddo
 c             charge conjugate
          incident.p.charge = -incident.p.charge
-         incident.p.subcode = -incident.p.subcode
+         if(incident.p.code .ne. kgnuc) then
+            incident.p.subcode = -incident.p.subcode
+         endif
       endif
 c           convert it to 'xyz' system
       call ctransVectZx(1, DetZaxis, DetXaxis, AngleAtObsCopy, 
@@ -289,27 +294,43 @@ c          set time 0
       incident.t = 0.
       incident.wgt = 1.       ! weight is 1.
 
-c           Next obs site
-      if( Upgoing ) then
-ccc         incident.where = NoOfSites
-         do i = NoOfSites, 1, -1
-            if( HeightOfInj .lt. ObsSites(i).pos.height ) then
-               incident.where = i
-               goto 33
-            endif
-         enddo
-         incident.where = 0
-      else
-ccc         incident.where = 1     
-         do i = 1, NoOfSites
-            if( HeightOfInj .gt. ObsSites(i).pos.height ) then
-               incident.where = i
-               goto 33
-            endif
-         enddo
-         incident.where = NoOfSites + 1
+
+      do i = 1, NoOfSites
+         if( HeightOfInj .gt. ObsSites(i).pos.height ) then
+            incident.where = i
+            goto 222
+         endif
+      enddo
+      if(HeightOfInj .lt. BorderHeightL) then
+         call cerrorMsg('Injection height is < BorderHeightL',0)
       endif
- 33   continue
+      incident.where = NoOfSites + 1
+ 222  continue
+      if(HeightOfInj .gt. BorderHeightH) then
+         call cerrorMsg('Injection height is > BorderHeightH',0)
+      endif
+
+c           Next obs site
+c      if( Upgoing ) then
+ccc         incident.where = NoOfSites
+c         do i = NoOfSites, 1, -1
+c            if( HeightOfInj .lt. ObsSites(i).pos.height ) then
+c               incident.where = i
+c               goto 33
+c            endif
+c         enddo
+c         incident.where = 0
+c      else
+ccc         incident.where = 1     
+c         do i = 1, NoOfSites
+c            if( HeightOfInj .gt. ObsSites(i).pos.height ) then
+c               incident.where = i
+c               goto 33
+c            endif
+c         enddo
+c         incident.where = NoOfSites + 1
+c      endif
+c33   continue
 
       incident.asflag = 0
       incident.pos.colheight = Infty  ! latest nuc. collision height
@@ -511,6 +532,7 @@ c
 c       ************************* see if geomagnetic cut or not.
         subroutine cifCutOff(icon)
         implicit none
+#include "Zglobalc.h"
 #include "Zobs.h"
 #include "Zobsp.h"
 #include "Ztrack.h"
@@ -528,26 +550,42 @@ c       ************************* see if geomagnetic cut or not.
          if(inc.p.charge .eq. 0) then
             icon = 0
          else
-c            angleatOb is down going ptcl's one, change sign
-            angleatOb.r(1) = - angleatOb.r(1)
-            angleatOb.r(2) = - angleatOb.r(2)
-            angleatOb.r(3) = - angleatOb.r(3)
-c             convert to theta fai in deg
-            call kdir2deg(angleatOb.r(1), angleatOb.r(2),
-     *      angleatOb.r(3), theta, azm)
+            if(Rdatafmt .le. 4) then
+c              angleatOb is down going ptcl's one, change sign
+               angleatOb.r(1) = - angleatOb.r(1)
+               angleatOb.r(2) = - angleatOb.r(2)
+               angleatOb.r(3) = - angleatOb.r(3)
+c                 convert to theta fai in deg
+               call kdir2deg(angleatOb.r(1), angleatOb.r(2),
+     *          angleatOb.r(3), theta, azm)
 c
-c               azm is given from the current x-axis  (+ is counter
-c              clock wise) The x-axis is XaxisFromSouth
-c            degrees from the south in counter clockwise.
-c            convert azm so that measured from the south
+c                 azm is given from the current x-axis  (+ is counter
+c                 clock wise) The x-axis is XaxisFromSouth
+c                 degrees from the south in counter clockwise.
+c                 convert azm so that measured from the south
 c
-            azm = mod(azm+ XaxisFromSouth, 360.d0)
-            if(ZenValue .eq. 'cos') then
-c                table zenith is in cos
-               zen = angleatOb.r(3)
+               azm = mod(azm+ XaxisFromSouth, 360.d0)
+               if(ZenValue .eq. 'cos') then
+c                    table zenith is in cos
+                  zen = angleatOb.r(3)
+               else
+                  zen = theta
+               endif
+            elseif(Rdatafmt .eq. 5) then
+c                 in this case, azm is longitude; zen is latitude or cos(lati)
+c       
+               zen =  atan2( inc.pos.xyz.z, 
+     *                sqrt(inc.pos.xyz.x**2+inc.pos.xyz.y**2) )
+               if(ZenValue .eq. 'cos') then
+                  zen = cos( zen-pi/2.0d0 )
+               else
+                  zen = zen*Todeg
+               endif
+               azm = atan2(inc.pos.xyz.y, inc.pos.xyz.x)*Todeg
             else
-               zen = theta
+               call cerrorMsg('dataformat for cut off invalid',0)
             endif
+
             p = sqrt(inc.p.fm.p(4)**2 - inc.p.mass**2)
             rig = p/abs(inc.p.charge)
             call crigCut(azm, zen, rig, prob)
@@ -559,3 +597,5 @@ c                table zenith is in cos
             endif
          endif
          end
+
+
