@@ -34,7 +34,6 @@ c
 c          call cconv_prim_e(Prim)   ! to total energy
            call cconv_prim_e(Prim.each(Prim.label), Prim.sampled_e, 
      *      Prim.particle)         
-
            p = Prim.particle
            Prim.NoOfSamplings =  Prim.NoOfSamplings  + 1 ! update counter.
            Prim.NoOfSampComp(Prim.label, 1) =
@@ -90,13 +89,6 @@ c
         if( each.no_of_seg .eq. 0) then
            p_or_e = each.emin       ! = emax
         else
-c              discard E> Emax
-           do while(.true.)
-              call rndc(u)
-              if(u .ge. each.norm_inte(each.no_of_seg +1)) goto 10
-           enddo
- 10        continue
-c
            call rndc(u)
            i = each.no_of_seg 
            do while (u .gt. each.norm_inte(i))
@@ -167,7 +159,9 @@ c            give polarization for muon primary
             aPtcl.fm.p(4) = inGeV + aPtcl.mass
          elseif(comp.etype .eq. 'e/n') then
             code = comp.code
-            if(code .ge. kdeut .and. 
+            if(code .eq. kgnuc) then
+               aPtcl.fm.p(4) = aPtcl.subcode * inGeV
+            elseif(code .ge. kalfa .and. 
      *         code .le. khvymax) then
                call cghvm(code, massn)
                aPtcl.fm.p(4) = massn * inGeV
@@ -176,7 +170,10 @@ c            give polarization for muon primary
             endif
          elseif(comp.etype .eq. 'ke/n') then
             code = comp.code
-            if(code .ge. kdeut .and. 
+            if(code .eq. kgnuc) then
+               aPtcl.fm.p(4) = aPtcl.subcode * inGeV +
+     *            aPtcl.mass
+            elseif(code .ge. kalfa .and. 
      *         code .le. khvymax) then
                call cghvm(code, massn)
                aPtcl.fm.p(4) = massn * inGeV +
@@ -187,7 +184,11 @@ c            give polarization for muon primary
             endif
 	 elseif(comp.etype .eq. 'p/n') then
             code = comp.code
-            if(code .ge. kdeut .and. 
+            if(code .eq. kgnuc) then
+               aPtcl.fm.p(4) =
+     *      	  sqrt( (aPtcl.subcode * inGeV) **2 + 
+     *            aPtcl.mass **2)
+            elseif(code .ge. kalfa .and. 
      *         code .le. khvymax) then
                call cghvm(code, massn)
                aPtcl.fm.p(4) =
@@ -197,6 +198,9 @@ c            give polarization for muon primary
                aPtcl.fm.p(4) = sqrt(inGeV**2 +
      *            aPtcl.mass**2)
             endif
+         elseif(comp.etype .eq. 'rig') then
+            aPtcl.fm.p(4) =sqrt(
+     *          ( inGeV*aPtcl.charge)**2 + aPtcl.mass**2 )
          else
             write(*, *) ' energy type=', comp.etype,
      *                  ' invalid. label=', comp.label, ' symb =',
@@ -242,7 +246,9 @@ c
 
          elseif(comp.etype .eq. 'e/n') then
             code = comp.code
-            if(code .ge. kdeut .and. 
+            if(code .eq. kgnuc) then
+               Ex = E/aPtcl.subcode
+            elseif(code .ge. kalfa .and. 
      *         code .le. khvymax) then
                call cghvm(code, massn)
                Ex = E/massn
@@ -251,7 +257,9 @@ c
             endif
          elseif(comp.etype .eq. 'ke/n') then
             code = comp.code
-            if(code .ge. kdeut .and. 
+            if( code .eq. kgnuc ) then
+               Ex =( E -   aPtcl.mass)/aPtcl.subcode
+            elseif(code .ge. kalfa .and. 
      *         code .le. khvymax) then
                call cghvm(code, massn)
                Ex =( E -   aPtcl.mass)/massn
@@ -260,13 +268,17 @@ c
             endif
 	 elseif(comp.etype .eq. 'p/n') then
             code = comp.code
-            if(code .ge. kdeut .and. 
+            if( code .eq. kgnuc) then
+               Ex =sqrt( E**2 -   aPtcl.mass **2)/aPtcl.subcode
+            elseif(code .ge. kalfa .and. 
      *         code .le. khvymax) then
                call cghvm(code, massn)
                Ex =sqrt( E**2 -   aPtcl.mass **2)/massn
             else
                Ex = sqrt(E**2 - aPtcl.mass**2)
             endif
+         elseif(comp.etype .eq. 'rig') then
+            Ex = sqrt( E**2 - aPtcl.mass**2) /aPtcl.charge
          else
             write(*, *) ' energy type=', comp.etype,
      *                  ' invalid. label=', comp.label, ' symb =',
@@ -276,7 +288,7 @@ c
         e_or_p = Ex/ comp.togev
         end
 c       *******************************************************
-c       *  cqPrimE: inquire sampled primary energy or p
+c       *  cqPrimE: inquire sampled primary energy or p or rigidity
 c       *                    as it is
 c       *******************************************************
 c
@@ -291,7 +303,7 @@ c
         call cqPrimE0(Prim, p_or_e)
         end
 c       *******************************************************
-c       *  cqPrimE0: inquire sampled primary energy or p
+c       *  cqPrimE0: inquire sampled primary energy or p or rigidity
 c       *                     as it is
 c       *******************************************************
 c
