@@ -75,157 +75,160 @@ c -------------------------------------tracking a ptcl
 #include  "Zobsv.h"
 #include  "Zincidentv.h"
 #include  "Zcode.h"
-
+c    
 c                next is for DEBUG
 
-
       real*8 cosangle
       character*70 msg
       integer nextwhere
 cc      integer icon
 
+#if DEBUG == 1
+      call checkstat('before fixModel')
+#endif
 
-         call cfixMedia   ! 
+      call cfixModel( TrackBefMove.p )      ! fix interaction model.
+      call cfixMedia            ! 
 c           sample interaction length.  The path may
 c           be truncated to a shorter one than really sampled.
 c           In that case, MoveStat == Truncated.
-         call csampIntL
 #if DEBUG == 1
-         call checkstat('after csampIntl')
+      call checkstat('before csampIntl')
+#endif
+
+      call csampIntL
+
+#if DEBUG == 1
+      call checkstat('after csampIntl')
 #endif
 c           Truncate the path if it is too long. Note, the truncated
 c           path in the above process may be again truncated to
 c           a shorter one. This happens, for example, if ptcl energy
 c           is low.  Path inf is reset in IntInfArray.
-         call ctruncPath
+      call ctruncPath
 #if DEBUG == 1
-         call checkstat('after ctruncPath')
+      call checkstat('after ctruncPath')
 #endif
 
 c           compute path end inf. including scattering and
 c           mag. deflection.  Path end inf is set in MovedTrack
-         call ccompPathEnd
+      call ccompPathEnd
 #if DEBUG == 1
-         call checkstat('after ccompPathEnd')
+      call checkstat('after ccompPathEnd')
 #endif
 c           see if MovedTrack crosses an observation site.
 c         (or reaches BorderHeightL)  If so, reset MovedTrack. 
-            call cifXObsSite(nextwhere)
-#if DEBUG == 4
-            call checkstat('after cifXObsSite')
+      call cifXObsSite(nextwhere)
+#if DEBUG == 1
+      call checkstat('after cifXObsSite')
 #endif
-         if(Trace .ne. 0) then
-            call cputTrInfo     ! put trace info.
-         endif
+      if(Trace .ne. 0) then
+         call cputTrInfo        ! put trace info.
+      endif
 #if DETAILED_TRACKING >= 3
 c            the user may kill the ptcl
-         call cobservation(8)
+      call cobservation(8)
 #endif
 
 
 c     
-         if(MoveStat .eq. Truncated) then
+      if(MoveStat .eq. Truncated) then
 c           see if truncation is really ok.  for energy = 0, 
 c           if anti ptcl, it should be anihilated, if decayabl,
 c           it should be decayed.
-            if(MovedTrack.p.fm.p(4) .eq. MovedTrack.p.mass) then
-               if(MovedTrack.p.subcode .eq. antip) then
-                  MoveStat = ToInteract
-               elseif(MovedTrack.p.code .eq. kmuon) then
-                  MoveStat = ToInteract
-               elseif(MovedTrack.p.code .eq. kpion) then
-                  MoveStat = ToInteract
-               elseif(MovedTrack.p.code .eq. kkaon) then
-                  MoveStat = ToInteract
-               endif
+         if(MovedTrack.p.fm.p(4) .eq. MovedTrack.p.mass) then
+            if(MovedTrack.p.subcode .eq. antip) then
+               MoveStat = ToInteract
+            elseif(MovedTrack.p.code .eq. kmuon) then
+               MoveStat = ToInteract
+            elseif(MovedTrack.p.code .eq. kpion) then
+               MoveStat = ToInteract
+            elseif(MovedTrack.p.code .eq. kkaon) then
+               MoveStat = ToInteract
             endif
-         endif 
+         endif
+      endif 
 
-         if(MoveStat .eq. Truncated) then
+      if(MoveStat .eq. Truncated) then
 c              stack current ptcl
-              call cpush(MovedTrack)
-         elseif(MoveStat .eq. ToInteract ) then
-            if(Zfirst .eq. 0.) then
-               Zfirst = MovedTrack.pos.depth
-c                  reset minimum time to reach the obs level (time from this
-c                  hight to the obs. level), if no mag. exists until
+         call cpush(MovedTrack)
+      elseif(MoveStat .eq. ToInteract ) then
+         if(Zfirst.pos.depth .eq. 0.) then
+c             reset minimum time to reach the obs level (time from this
+c             hight to the obs. level), if no mag. exists until
 c                  the first collision point. or ptcl goes streight
-               if(mod(HowGeomag, 2) .eq. 1 .or. 
-     *             IncidentCopy.p.charge .eq. 0) then
-                  call csetMinTime(MovedTrack)
-               endif
-            endif
-#if DETAILED_TRACKING >= 1 
-            call cobservation(4)
-#endif
-            call cinteraction
-         elseif(MoveStat .eq. ToBeObserved) then
-            if(MovedTrack.p.fm.p(4)-MovedTrack.p.mass 
-     *          .gt. KEminObs) then
-c                  call only for high energy particles
-c                  (at AS generation, some ptcl may have < KEminObs)
-               call cobservation(2)
-            endif
-c               update observation place
-            if(abs(ObsPlane) .eq. horizontal) then
-               cosangle = MovedTrack.vec.coszenith
-            elseif(abs(ObsPlane) .eq. perpendicular) then
-               call cscalerProd(MovedTrack.vec.w, DcAtObsXyz,
-     *               cosangle)
-            endif
-c            elseif(ObsPlane .eq. spherical) then
-c               call cscalerProd(MovedTrack.vec.w, MovedTrack.pos,
-c     *               cosangle)
-c               cosangle = - cosangle
-c            else
-c               call 
-c     *         cerrorMsg('should not come here in tracking', 0)
-c            endif
-            if(ObsPlane .ne. spherical) then
-               if(cosangle .lt. 0.) then
-                  MovedTrack.where = MovedTrack.where - 1
-               else
-                  MovedTrack.where = MovedTrack.where + 1
-               endif
-c                  if more obs-site, stack current ptcl.
-               if(.not. Upgoing) then ! incident is downgoing
-                  if(MovedTrack.where .gt. EndLevel) then
-                                ! no need to stack; discard ptcl.
-                  else
-                     MovedTrack.where =max( MovedTrack.where, 1)
-                     call cpush(MovedTrack)
-                  endif
-               else             !incident is  Upgoing
-                  if(MovedTrack.where .lt.1 ) then
-                                ! no need to stack
-                  else
-                     MovedTrack.where =
-     *                         min(MovedTrack.where, EndLevel)
-                     call cpush(MovedTrack)
-                  endif
-               endif
+            if(mod(HowGeomag, 2) .eq. 1 .or. 
+     *           IncidentCopy.p.charge .eq. 0 .and.
+     *           ObsPlane .ne. 3) then
+               call csetMinTime(MovedTrack)
             else
-               MovedTrack.where = nextwhere
-               call cpush(MovedTrack)
+               MovedTrack.t = 0.
             endif
-         elseif(MoveStat .eq. BorderL) then
-            call cobservation(3)
-         elseif(MoveStat .eq. BorderH) then
-            call cobservation(1)
-         elseif(MoveStat .eq. Dead) then   
+            Zfirst = MovedTrack
+         endif
+#if DETAILED_TRACKING >= 1 
+         call cobservation(4)
+#endif
+
+#if DEBUG == 1
+         call checkstat('before cinteraction')
+#endif
+         call cinteraction
+      elseif(MoveStat .eq. ToBeObserved) then
+         if(MovedTrack.p.fm.p(4)-MovedTrack.p.mass 
+     *        .gt. KEminObs) then
+c             call only for high energy particles
+c                  (at AS generation, some ptcl may have < KEminObs)
+            call cobservation(2)
+         endif
+c               update observation place
+         if(abs(ObsPlane) .eq. perpendicular) then
+            call cscalerProd(MovedTrack.vec.w, DcAtObsXyz,
+     *               cosangle)
+            if(cosangle .lt. 0.) then
+               MovedTrack.where = MovedTrack.where - 1
+            else
+               MovedTrack.where = MovedTrack.where + 1
+            endif
+c                  if more obs-site, stack current ptcl.
+            if(.not. Upgoing) then ! incident is downgoing
+               if(MovedTrack.where .gt. EndLevel) then
+                                ! no need to stack; discard ptcl.
+               else
+                  MovedTrack.where =max( MovedTrack.where, 1)
+                  call cpush(MovedTrack)
+               endif
+            else                !incident is  Upgoing
+               if(MovedTrack.where .lt.1 ) then
+                                ! no need to stack
+               else
+                  MovedTrack.where =
+     *                         min(MovedTrack.where, EndLevel)
+                  call cpush(MovedTrack)
+               endif
+            endif
+         else
+            MovedTrack.where = nextwhere
+            call cpush(MovedTrack)
+         endif
+      elseif(MoveStat .eq. BorderL) then
+         call cobservation(3)
+      elseif(MoveStat .eq. BorderH) then
+         call cobservation(1)
+      elseif(MoveStat .eq. Dead) then   
 c            actually this will not happen. branch is
 c           made before this
 #if DETAILED_TRACKING >= 1
-            call cobservation(5)
+         call cobservation(5)
 #endif
-         elseif(MoveStat .eq. AngleLimit) then
+      elseif(MoveStat .eq. AngleLimit) then
 #if DETAILED_TRACKING >= 2
-            call cobservation(7)
+         call cobservation(7)
 #endif
-         else
-            write(msg, *) ' movestat=',MoveStat,' invalid'
-           call cerrorMsg(msg, 0)
-         endif   
+      else
+         write(msg, *) ' movestat=',MoveStat,' invalid'
+         call cerrorMsg(msg, 0)
+      endif   
       end
 #if DEBUG > 0
       subroutine checkstat(str)
@@ -237,6 +240,10 @@ c           made before this
 #include  "Zobsv.h"
       character*(*) str
       integer i
+      integer nc
+      data nc/0/
+      nc = nc + 1
+      if(nc .gt. 750) then
 
 c         if(TrackBefMove.p.code .eq. 6
 c     *     .and. TrackBefMove.p.charge .eq. -1) then
@@ -246,14 +253,16 @@ c     *     .and. TrackBefMove.p.charge .eq. -1) then
             write(*, *) ' where', TrackBefMove.where
             write(*,*)  ' h==', TrackBefMove.pos.height,
      *       ' d=', TrackBefMove.pos.depth
-c            write(*,*) ' cos=',TrackBefMove.vec.coszenith
-c            do i = 1, NumberOfInte
-c               write(*, *) ' process=',IntInfArray(i).process
-c               write(*, *) ' thickness=',IntInfArray(i).thickness
-c               write(*, *) ' length=',IntInfArray(1).length
-c            enddo
+            write(*,*) ' cos=',TrackBefMove.vec.coszenith
+            do i = 1, NumberOfInte
+               write(*, *) ' process=',IntInfArray(i).process
+               write(*, *) ' thickness=',IntInfArray(i).thickness
+               write(*, *) ' length=',IntInfArray(1).length
+            enddo
+            write(*,*)'  ProcessNo=', ProcessNo
             write(*,*)  '--------------'
 c         endif
+         endif
       end
 #endif
 c-------------------------------------------------------
@@ -296,7 +305,9 @@ c         argon
       if(HowGeomag .le. 2 .or. HowGeomag .eq. 31) then
 c             distant; change of B is < 1 % 
          call clengSmallBC(TrackBefMove, distant)
-
+c   **********
+         distant = distant/10.
+c   **********
          if( (TrackBefMove.pos.xyz.r(1) - x)**2 + 
      *        (TrackBefMove.pos.xyz.r(2) - y)**2 + 
      *        (TrackBefMove.pos.xyz.r(3) - z)**2 
@@ -369,7 +380,7 @@ c
             call csampNEPIntL   ! non Electron Photon  Interaction.
          endif
          call cfixProc
-         if(.not. Freec .and. Zfirst .eq. 0.) then
+         if(.not. Freec .and. Zfirst.pos.depth .eq. 0.) then
             IntInfArray(ProcessNo).length = 0.
             IntInfArray(ProcessNo).thickness = 0.
          endif
@@ -385,7 +396,7 @@ c     **************************** cfixProc **********
 #include  "Zearth.h"
 
 
-      real*8 h, leng, t, minlen, clen2thick
+      real*8 h, leng, t, minlen, clen2thick, pcut
 c     
       integer i, jcut
 c     
@@ -398,8 +409,10 @@ c              get vertical height
 c              convert kg/m2 into length
             if(NumberOfInte .eq. 1 .or.
      *        IntInfArray(i).thickness .ne. Infty) then
-               call cthick2len(h, TrackBefMove.vec.coszenith, 
-     *         IntInfArray(i).thickness, leng, t, jcut)
+c               call cthick2len(h, TrackBefMove.vec.coszenith, 
+c     *         IntInfArray(i).thickness, leng, t, jcut)
+               call cthick2len(TrackBefMove,
+     *         IntInfArray(i).thickness, leng, t, jcut) 
                if(leng .le. 0.) then
                   leng = 1.d-3
                endif
@@ -422,7 +435,26 @@ c              convert kg/m2 into length
             minlen = leng
          endif
       enddo
+      if(leng .ge. minlen) then
+         ProcessNo = 1
+         IntInfArray(i).length = 1.e5
+      endif         
       if(IntInfArray(ProcessNo).decay .or. jcut .ne. 0) then
+c         In the case  of muon, if individual knockon process  
+c       is neglected (by parameter setting or with high Emin)
+c       the length could be quite large (say, 6000  km).
+c       and result in the  error in the next call.
+c       To avoid that, we cut the path here
+c
+         if( TrackBefMove.vec.coszenith .lt. 0.) then
+            pcut = 300.d3
+         else
+            pcut = 10.d3
+         endif
+         if(IntInfArray(ProcessNo).length .gt. pcut) then
+            MoveStat = Truncated
+            IntInfArray(ProcessNo).length  = pcut
+         endif
          IntInfArray(ProcessNo).thickness = clen2thick(h, 
      *      TrackBefMove.vec.coszenith, 
      *      IntInfArray(ProcessNo).length )
@@ -442,7 +474,7 @@ c        an observation depth.
 c
       call cmaxMovLen(leng, thick)
 
-      if(leng .lt. IntInfArray(ProcessNo).length) then
+      if(leng .lt. IntInfArray(ProcessNo).length ) then
          MoveStat = Truncated
          IntInfArray(ProcessNo).length = leng
          IntInfArray(ProcessNo).thickness  = thick
