@@ -12,7 +12,7 @@ c
       maxZ = MinZen + DZen * ( ZenSize -1 )
       do azm = MinAzm, 360.00001d0, 5.d0
          do zen = MinZen, maxZ, DZen/2.
-            call crigCut(azm, zen, rigcut)
+            call cgetrigCut(azm, zen, rigcut)
             write(*, *) sngl(azm), sngl(zen), sngl(rigcut)
          enddo
          write(*, *)
